@@ -1,4 +1,4 @@
 # read in the example data (generated, not real student data)
 sdf <- readNAEP(system.file("extdata/data", "M36NT2PM.dat", package = "NAEPprimer"))
 
-getPlausibleValue("composite", sdf)
+getPlausibleValue(var="composite", data=sdf)
